@@ -1,13 +1,13 @@
 package Net::IPAM::Tree;
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 use 5.10.0;
 use strict;
 use warnings;
 use utf8;
 
-use Carp qw(croak);
+use Carp qw(carp croak);
 use Scalar::Util qw(blessed);
 ###
 use namespace::clean;
@@ -15,10 +15,6 @@ use namespace::clean;
 use Net::IPAM::Block;
 use Net::IPAM::Tree::Node;
 
-=pod
-
-=encoding utf8
-
 =head1 NAME
 
 Net::IPAM::Tree - A CIDR/Block tree library for fast IP lookup with longest-prefix-match.
@@ -32,7 +28,7 @@ This isn't possible for general blocks not represented by bitmasks, every tree i
 
 The complexity for tree operations is in worst case O(h * log n) with h <= 128 (IPv6) or h <=32 (IPv4).
 
-=cut
+=encoding utf8
 
 =head1 SYNOPSIS
 
@@ -69,7 +65,7 @@ Create Net::IPAM::Tree object.
   my $t = Net::IPAM::Tree->new;
 
 The only optional argument is a coderef for an error handler.
-With no error callback L</insert> just calls C<< warn() >> on duplicate items.
+With no error callback L</insert> just calls C<< carp() >> on duplicate items.
 
 The error callback gets the duplicate block as argument.
 
@@ -90,7 +86,7 @@ sub new {
     $self->{error_cb} = $_[1];
   }
   else {
-    $self->{error_cb} = sub { warn("duplicate block during insert: $_[0]\n") };
+    $self->{error_cb} = sub { carp("duplicate block during insert: $_[0]") };
   }
 
   return $self;
@@ -438,7 +434,6 @@ This software is copyright (c) 2020 by Karl Gaissmaier.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-
 =cut
 
 1;    # End of Net::IPAM::Tree
